@@ -103,21 +103,21 @@ func (s *localStack) ImportDeployment(ctx context.Context, deployment *apitype.U
 }
 
 type localStackSummary struct {
-	s *localStack
+	name backend.StackReference
+	chk  *apitype.CheckpointV3
 }
 
-func newLocalStackSummary(s *localStack) localStackSummary {
-	return localStackSummary{s}
+func newLocalStackSummary(name backend.StackReference, chk *apitype.CheckpointV3) localStackSummary {
+	return localStackSummary{name: name, chk: chk}
 }
 
 func (lss localStackSummary) Name() backend.StackReference {
-	return lss.s.Ref()
+	return lss.name
 }
 
 func (lss localStackSummary) LastUpdate() *time.Time {
-	snap := lss.s.snapshot
-	if snap != nil {
-		if t := snap.Manifest.Time; !t.IsZero() {
+	if lss.chk != nil && lss.chk.Latest != nil {
+		if t := lss.chk.Latest.Manifest.Time; !t.IsZero() {
 			return &t
 		}
 	}
@@ -125,9 +125,8 @@ func (lss localStackSummary) LastUpdate() *time.Time {
 }
 
 func (lss localStackSummary) ResourceCount() *int {
-	snap := lss.s.snapshot
-	if snap != nil {
-		count := len(snap.Resources)
+	if lss.chk != nil && lss.chk.Latest != nil {
+		count := len(lss.chk.Latest.Resources)
 		return &count
 	}
 	return nil
