@@ -18,6 +18,7 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"net/url"
 	"os"
@@ -30,7 +31,7 @@ import (
 
 	multierror "github.com/hashicorp/go-multierror"
 	opentracing "github.com/opentracing/opentracing-go"
-	"github.com/pkg/errors"
+
 	survey "gopkg.in/AlecAivazis/survey.v1"
 	surveycore "gopkg.in/AlecAivazis/survey.v1/core"
 	git "gopkg.in/src-d/go-git.v4"
@@ -99,7 +100,7 @@ func isFilestateBackend(opts display.Options) (bool, error) {
 
 	url, err := workspace.GetCurrentCloudURL()
 	if err != nil {
-		return false, errors.Wrapf(err, "could not get cloud url")
+		return false, fmt.Errorf("could not get cloud url: %w", err)
 	}
 
 	return filestate.IsFileStateBackendURL(url), nil
@@ -112,7 +113,7 @@ func currentBackend(opts display.Options) (backend.Backend, error) {
 
 	url, err := workspace.GetCurrentCloudURL()
 	if err != nil {
-		return nil, errors.Wrapf(err, "could not get cloud url")
+		return nil, fmt.Errorf("could not get cloud url: %w", err)
 	}
 
 	if filestate.IsFileStateBackendURL(url) {
@@ -184,7 +185,7 @@ func createSecretsManager(b backend.Backend, stackRef backend.StackReference, se
 		if strings.HasPrefix(secretsProvider, "azurekeyvault://") {
 			parsed, err := url.Parse(secretsProvider)
 			if err != nil {
-				return errors.Wrap(err, "failed to parse secrets provider URL")
+				return fmt.Errorf("failed to parse secrets provider URL: %w", err)
 			}
 
 			if parsed.Query().Get("algorithm") == "" {
@@ -215,7 +216,7 @@ func createStack(
 		if _, ok := err.(*backend.OverStackLimitError); ok {
 			return nil, err
 		}
-		return nil, errors.Wrapf(err, "could not create stack")
+		return nil, fmt.Errorf("could not create stack: %w", err)
 	}
 
 	if err := createSecretsManager(b, stackRef, secretsProvider,
@@ -272,7 +273,7 @@ func requireStack(
 		return createStack(b, stackRef, nil, setCurrent, "")
 	}
 
-	return nil, errors.Errorf("no stack named '%s' found", stackName)
+	return nil, fmt.Errorf("no stack named '%s' found", stackName)
 }
 
 func requireCurrentStack(offerNew bool, opts display.Options, setCurrent bool) (backend.Stack, error) {
@@ -324,7 +325,7 @@ func chooseStack(
 	for {
 		summaries, outContToken, err := b.ListStacks(ctx, backend.ListStacksFilter{Project: &project}, inContToken)
 		if err != nil {
-			return nil, errors.Wrapf(err, "could not query backend for stacks")
+			return nil, fmt.Errorf("could not query backend for stacks: %w", err)
 		}
 
 		allSummaries = append(allSummaries, summaries...)
@@ -404,15 +405,15 @@ func chooseStack(
 	// With the stack name selected, look it up from the backend.
 	stackRef, err := b.ParseStackReference(option)
 	if err != nil {
-		return nil, errors.Wrap(err, "parsing selected stack")
+		return nil, fmt.Errorf("parsing selected stack: %w", err)
 	}
 	// GetStack may return (nil, nil) if the stack isn't found.
 	stack, err := b.GetStack(ctx, stackRef)
 	if err != nil {
-		return nil, errors.Wrap(err, "getting selected stack")
+		return nil, fmt.Errorf("getting selected stack: %w", err)
 	}
 	if stack == nil {
-		return nil, errors.Errorf("no stack named '%s' found", stackRef)
+		return nil, fmt.Errorf("no stack named '%s' found", stackRef)
 	}
 
 	// If setCurrent is true, we'll persist this choice so it'll be used for future CLI operations.
@@ -437,7 +438,7 @@ func parseAndSaveConfigArray(s backend.Stack, configArray []string, path bool) e
 	}
 
 	if err = saveConfig(s, commandLineConfig); err != nil {
-		return errors.Wrap(err, "saving config")
+		return fmt.Errorf("saving config: %w", err)
 	}
 	return nil
 }
@@ -472,8 +473,9 @@ func readProject() (*workspace.Project, string, error) {
 	// Now that we got here, we have a path, so we will try to load it.
 	path, err := workspace.DetectProjectPathFrom(pwd)
 	if err != nil {
-		return nil, "", errors.Wrapf(err, "failed to find current Pulumi project because of "+
-			"an error when searching for the Pulumi.yaml file (searching upwards from %s)", pwd)
+		return nil, "", fmt.Errorf("failed to find current Pulumi project because of "+
+			"an error when searching for the Pulumi.yaml file (searching upwards from %s)"+": %w", pwd, err)
+
 	} else if path == "" {
 		return nil, "", fmt.Errorf(
 			"no Pulumi.yaml project file found (searching upwards from %s). If you have not "+
@@ -481,7 +483,7 @@ func readProject() (*workspace.Project, string, error) {
 	}
 	proj, err := workspace.LoadProject(path)
 	if err != nil {
-		return nil, "", errors.Wrapf(err, "failed to load Pulumi project located at %q", path)
+		return nil, "", fmt.Errorf("failed to load Pulumi project located at %q: %w", path, err)
 	}
 
 	return proj, filepath.Dir(path), nil
@@ -499,14 +501,15 @@ func readPolicyProject() (*workspace.PolicyPackProject, string, string, error) {
 	// Now that we got here, we have a path, so we will try to load it.
 	path, err := workspace.DetectPolicyPackPathFrom(pwd)
 	if err != nil {
-		return nil, "", "", errors.Wrapf(err, "failed to find current Pulumi project because of "+
-			"an error when searching for the PulumiPolicy.yaml file (searching upwards from %s)", pwd)
+		return nil, "", "", fmt.Errorf("failed to find current Pulumi project because of "+
+			"an error when searching for the PulumiPolicy.yaml file (searching upwards from %s)"+": %w", pwd, err)
+
 	} else if path == "" {
 		return nil, "", "", fmt.Errorf("no PulumiPolicy.yaml project file found (searching upwards from %s)", pwd)
 	}
 	proj, err := workspace.LoadPolicyPack(path)
 	if err != nil {
-		return nil, "", "", errors.Wrapf(err, "failed to load Pulumi policy project located at %q", path)
+		return nil, "", "", fmt.Errorf("failed to load Pulumi policy project located at %q: %w", path, err)
 	}
 
 	return proj, path, filepath.Dir(path), nil
@@ -540,7 +543,7 @@ func isGitWorkTreeDirty(repoRoot string) (bool, error) {
 		if ee, ok := err.(*exec.ExitError); ok {
 			ee.Stderr = stderr.Bytes()
 		}
-		return false, errors.Wrapf(err, "'git status' failed")
+		return false, fmt.Errorf("'git status' failed: %w", err)
 	}
 
 	return bool(anyOutput), nil
@@ -572,7 +575,7 @@ func addGitMetadata(repoRoot string, m *backend.UpdateMetadata) error {
 	// Gather git-related data as appropriate. (Returns nil, nil if no repo found.)
 	repo, err := gitutil.GetGitRepository(repoRoot)
 	if err != nil {
-		return errors.Wrapf(err, "detecting Git repository")
+		return fmt.Errorf("detecting Git repository: %w", err)
 	}
 	if repo == nil {
 		return nil
@@ -596,7 +599,7 @@ func AddGitRemoteMetadataToMap(repo *git.Repository, env map[string]string) erro
 	// Get the remote URL for this repo.
 	remoteURL, err := gitutil.GetGitRemoteURL(repo, "origin")
 	if err != nil {
-		return errors.Wrap(err, "detecting Git remote URL")
+		return fmt.Errorf("detecting Git remote URL: %w", err)
 	}
 	if remoteURL == "" {
 		return nil
@@ -615,7 +618,7 @@ func addVCSMetadataToEnvironment(remoteURL string, env map[string]string) error
 	// We don't require a cloud-hosted VCS, so swallow errors.
 	vcsInfo, err := gitutil.TryGetVCSInfo(remoteURL)
 	if err != nil {
-		return errors.Wrap(err, "detecting VCS project information")
+		return fmt.Errorf("detecting VCS project information: %w", err)
 	}
 	env[backend.VCSRepoOwner] = vcsInfo.Owner
 	env[backend.VCSRepoName] = vcsInfo.Repo
@@ -633,14 +636,14 @@ func addGitCommitMetadata(repo *git.Repository, repoRoot string, m *backend.Upda
 	// Commit at HEAD
 	head, err := repo.Head()
 	if err != nil {
-		return errors.Wrap(err, "getting repository HEAD")
+		return fmt.Errorf("getting repository HEAD: %w", err)
 	}
 
 	hash := head.Hash()
 	m.Environment[backend.GitHead] = hash.String()
 	commit, commitErr := repo.CommitObject(hash)
 	if commitErr != nil {
-		return errors.Wrap(commitErr, "getting HEAD commit info")
+		return fmt.Errorf("getting HEAD commit info: %w", commitErr)
 	}
 
 	// If in detached head, will be "HEAD", and fallback to use value from CI/CD system if possible.
@@ -671,7 +674,7 @@ func addGitCommitMetadata(repo *git.Repository, repoRoot string, m *backend.Upda
 	// If the worktree is dirty, set a bit, as this could be a mistake.
 	isDirty, err := isGitWorkTreeDirty(repoRoot)
 	if err != nil {
-		return errors.Wrapf(err, "checking git worktree dirty state")
+		return fmt.Errorf("checking git worktree dirty state: %w", err)
 	}
 	m.Environment[backend.GitDirty] = strconv.FormatBool(isDirty)
 
@@ -837,7 +840,7 @@ func checkDeploymentVersionError(err error, stackName string) error {
 		return fmt.Errorf("the stack '%s' is newer than what this version of the Pulumi CLI understands. "+
 			"Please update your version of the Pulumi CLI", stackName)
 	}
-	return errors.Wrap(err, "could not deserialize deployment")
+	return fmt.Errorf("could not deserialize deployment: %w", err)
 }
 
 func getRefreshOption(proj *workspace.Project, refresh string) (bool, error) {
@@ -862,3 +865,20 @@ func getRefreshOption(proj *workspace.Project, refresh string) (bool, error) {
 	// the default functionality right now is to always skip a refresh
 	return false, nil
 }
+
+func buildStackName(stackName string) (string, error) {
+	if strings.Count(stackName, "/") == 2 {
+		return stackName, nil
+	}
+
+	defaultOrg, err := workspace.GetBackendConfigDefaultOrg()
+	if err != nil {
+		return "", err
+	}
+
+	if defaultOrg != "" {
+		return fmt.Sprintf("%s/%s", defaultOrg, stackName), nil
+	}
+
+	return stackName, nil
+}
