@@ -49,8 +49,9 @@ var programTests = []programTest{
 	{
 		Name:        "aws-fargate",
 		Description: "AWS Fargate",
+
+		// TODO[pulumi/pulumi#8440]
 		SkipCompile: codegen.NewStringSet("go"),
-		Skip:        codegen.NewStringSet("go", "python", "dotnet"),
 	},
 	{
 		Name:        "aws-s3-logging",
@@ -127,7 +128,6 @@ var programTests = []programTest{
 	{
 		Name:        "output-funcs-aws",
 		Description: "Output Versioned Functions",
-		Skip:        codegen.NewStringSet("go", "python", "dotnet"),
 	},
 }
 
