@@ -32,7 +32,6 @@ import (
 	"unicode"
 
 	"github.com/blang/semver"
-	"github.com/pkg/errors"
 
 	"github.com/pulumi/pulumi/pkg/v3/codegen"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/schema"
@@ -472,6 +471,11 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Resources
 	for _, r := range mod.resources {
+		if r.IsOverlay {
+			// This resource code is generated by the provider, so no further action is required.
+			continue
+		}
+
 		res, err := mod.genResource(r)
 		if err != nil {
 			return err
@@ -490,6 +494,11 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Functions
 	for _, f := range mod.functions {
+		if f.IsOverlay {
+			// This function code is generated by the provider, so no further action is required.
+			continue
+		}
+
 		fun, err := mod.genFunction(f)
 		if err != nil {
 			return err
@@ -523,6 +532,9 @@ func (mod *modContext) gen(fs fs) error {
 }
 
 func (mod *modContext) hasTypes(input bool) bool {
+	if allTypesAreOverlays(mod.types) {
+		return false
+	}
 	for _, t := range mod.types {
 		if input && mod.details(t).inputType {
 			return true
@@ -875,12 +887,31 @@ func (mod *modContext) genConfigStubs(variables []*schema.Property) (string, err
 	return w.String(), nil
 }
 
+func allTypesAreOverlays(types []*schema.ObjectType) bool {
+	for _, t := range types {
+		if !t.IsOverlay {
+			return false
+		}
+	}
+	return true
+}
+
 func (mod *modContext) genTypes(dir string, fs fs) error {
 	genTypes := func(file string, input bool) error {
 		w := &bytes.Buffer{}
 
+		if allTypesAreOverlays(mod.types) {
+			// If all resources in this module are overlays, skip further code generation.
+			return nil
+		}
+
 		imports := imports{}
 		for _, t := range mod.types {
+			if t.IsOverlay {
+				// This type is generated by the provider, so no further action is required.
+				continue
+			}
+
 			if input && mod.details(t).inputType {
 				visitObjectTypes(t.Properties, func(t schema.Type) {
 					switch t := t.(type) {
@@ -909,6 +940,11 @@ func (mod *modContext) genTypes(dir string, fs fs) error {
 		// Export only the symbols we want exported.
 		fmt.Fprintf(w, "__all__ = [\n")
 		for _, t := range mod.types {
+			if t.IsOverlay {
+				// This type is generated by the provider, so no further action is required.
+				continue
+			}
+
 			if input && mod.details(t).inputType || !input && mod.details(t).outputType {
 				fmt.Fprintf(w, "    '%s',\n", mod.unqualifiedObjectTypeName(t, input))
 			}
@@ -917,6 +953,11 @@ func (mod *modContext) genTypes(dir string, fs fs) error {
 
 		var hasTypes bool
 		for _, t := range mod.types {
+			if t.IsOverlay {
+				// This type is generated by the provider, so no further action is required.
+				continue
+			}
+
 			if input && mod.details(t).inputType {
 				if err := mod.genObjectType(w, t, true); err != nil {
 					return err
@@ -1062,8 +1103,7 @@ func (mod *modContext) genResource(res *schema.Resource) (string, error) {
 		for _, t := range mod.types {
 			if mod.details(t).inputType {
 				if mod.unqualifiedObjectTypeName(t, true) == resourceArgsName {
-					return "", errors.Errorf(
-						"resource args class named %s in %s conflicts with input type", resourceArgsName, mod.mod)
+					return "", fmt.Errorf("resource args class named %s in %s conflicts with input type", resourceArgsName, mod.mod)
 				}
 			}
 		}
@@ -1841,7 +1881,7 @@ func (mod *modContext) genEnum(w io.Writer, enum *schema.EnumType) error {
 			}
 		}
 	default:
-		return errors.Errorf("enums of type %s are not yet implemented for this language", enum.ElementType.String())
+		return fmt.Errorf("enums of type %s are not yet implemented for this language", enum.ElementType.String())
 	}
 
 	return nil
@@ -2012,15 +2052,15 @@ func genPackageMetadata(
 		// We expect a specific pattern of ">=version,<version" here.
 		matches := requirementRegex.FindStringSubmatch(pulumiReq)
 		if len(matches) != 2 {
-			return "", errors.Errorf("invalid requirement specifier \"%s\"; expected \">=version1,<version2\"", pulumiReq)
+			return "", fmt.Errorf("invalid requirement specifier \"%s\"; expected \">=version1,<version2\"", pulumiReq)
 		}
 
 		lowerBound, err := pep440VersionToSemver(matches[1])
 		if err != nil {
-			return "", errors.Errorf("invalid version for lower bound: %v", err)
+			return "", fmt.Errorf("invalid version for lower bound: %v", err)
 		}
 		if lowerBound.LT(oldestAllowedPulumi) {
-			return "", errors.Errorf("lower version bound must be at least %v", oldestAllowedPulumi)
+			return "", fmt.Errorf("lower version bound must be at least %v", oldestAllowedPulumi)
 		}
 	} else {
 		if requires == nil {
@@ -2502,7 +2542,7 @@ func getPrimitiveValue(value interface{}) (string, error) {
 	case reflect.String:
 		return fmt.Sprintf("'%s'", v.String()), nil
 	default:
-		return "", errors.Errorf("unsupported default value of type %T", value)
+		return "", fmt.Errorf("unsupported default value of type %T", value)
 	}
 }
 
@@ -2682,8 +2722,10 @@ func generateModuleContextMap(tool string, pkg *schema.Package, info PackageInfo
 				mod.types = append(mod.types, typ)
 			}
 		case *schema.EnumType:
-			mod := getModFromToken(typ.Token, pkg)
-			mod.enums = append(mod.enums, typ)
+			if !typ.IsOverlay {
+				mod := getModFromToken(typ.Token, pkg)
+				mod.enums = append(mod.enums, typ)
+			}
 		default:
 			continue
 		}
@@ -2735,6 +2777,11 @@ func LanguageResources(tool string, pkg *schema.Package) (map[string]LanguageRes
 			continue
 		}
 		for _, r := range mod.resources {
+			if r.IsOverlay {
+				// This resource code is generated by the provider, so no further action is required.
+				continue
+			}
+
 			packagePath := strings.Replace(modName, "/", ".", -1)
 			lr := LanguageResource{
 				Resource: r,
