@@ -17,6 +17,7 @@ package engine
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"path/filepath"
 	"sort"
@@ -24,7 +25,7 @@ import (
 	"sync"
 
 	"github.com/blang/semver"
-	"github.com/pkg/errors"
+
 	resourceanalyzer "github.com/pulumi/pulumi/pkg/v3/resource/analyzer"
 	"github.com/pulumi/pulumi/pkg/v3/resource/deploy"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/diag"
@@ -293,11 +294,11 @@ func installAndLoadPolicyPlugins(plugctx *plugin.Context, d diag.Sink, policies
 		config, validationErrors, err := resourceanalyzer.ReconcilePolicyPackConfig(
 			analyzerInfo.Policies, analyzerInfo.InitialConfig, configFromAPI)
 		if err != nil {
-			return errors.Wrapf(err, "reconciling config for %q", analyzerInfo.Name)
+			return fmt.Errorf("reconciling config for %q: %w", analyzerInfo.Name, err)
 		}
 		appendValidationErrors(analyzerInfo.Name, analyzerInfo.Version, validationErrors)
 		if err = analyzer.Configure(config); err != nil {
-			return errors.Wrapf(err, "configuring policy pack %q", analyzerInfo.Name)
+			return fmt.Errorf("configuring policy pack %q: %w", analyzerInfo.Name, err)
 		}
 	}
 
@@ -312,7 +313,7 @@ func installAndLoadPolicyPlugins(plugctx *plugin.Context, d diag.Sink, policies
 		if err != nil {
 			return err
 		} else if analyzer == nil {
-			return errors.Errorf("policy analyzer could not be loaded from path %q", pack.Path)
+			return fmt.Errorf("policy analyzer could not be loaded from path %q", pack.Path)
 		}
 
 		// Update the Policy Pack names now that we have loaded the plugins and can access the name.
@@ -325,7 +326,7 @@ func installAndLoadPolicyPlugins(plugctx *plugin.Context, d diag.Sink, policies
 		// Load config, reconcile & validate it, and pass it to the policy pack.
 		if !analyzerInfo.SupportsConfig {
 			if pack.Config != "" {
-				return errors.Errorf("policy pack %q at %q does not support config", analyzerInfo.Name, pack.Path)
+				return fmt.Errorf("policy pack %q at %q does not support config", analyzerInfo.Name, pack.Path)
 			}
 			continue
 		}
@@ -339,11 +340,11 @@ func installAndLoadPolicyPlugins(plugctx *plugin.Context, d diag.Sink, policies
 		config, validationErrors, err := resourceanalyzer.ReconcilePolicyPackConfig(
 			analyzerInfo.Policies, analyzerInfo.InitialConfig, configFromFile)
 		if err != nil {
-			return errors.Wrapf(err, "reconciling policy config for %q at %q", analyzerInfo.Name, pack.Path)
+			return fmt.Errorf("reconciling policy config for %q at %q: %w", analyzerInfo.Name, pack.Path, err)
 		}
 		appendValidationErrors(analyzerInfo.Name, analyzerInfo.Version, validationErrors)
 		if err = analyzer.Configure(config); err != nil {
-			return errors.Wrapf(err, "configuring policy pack %q at %q", analyzerInfo.Name, pack.Path)
+			return fmt.Errorf("configuring policy pack %q at %q: %w", analyzerInfo.Name, pack.Path, err)
 		}
 	}
 
