@@ -58,6 +58,21 @@ namespace Pulumi.Testing
             return new InvokeResponse { Return = await SerializeAsync(result).ConfigureAwait(false) };
         }
 
+        public async Task<CallResponse> CallAsync(CallRequest request)
+        {
+            // For now, we'll route both Invoke and Call through IMocks.CallAsync.
+            var args = ToDictionary(request.Args);
+
+            var result = await _mocks.CallAsync(new MockCallArgs
+                {
+                    Token = request.Tok,
+                    Args = args,
+                    Provider = request.Provider,
+                })
+                .ConfigureAwait(false);
+            return new CallResponse { Return = await SerializeAsync(result).ConfigureAwait(false) };
+        }
+
         public async Task<ReadResourceResponse> ReadResourceAsync(Resource resource, ReadResourceRequest request)
         {
             var (id, state) = await _mocks.NewResourceAsync(new MockResourceArgs
