@@ -915,20 +915,29 @@ func TestOutputValueMarshalling(t *testing.T) {
 
 					out := ctx.newOutput(anyOutputType, resources...)
 					out.getState().resolve(value.value, known, secret, nil)
+					inputs := Map{"value": out}
 
-					expected := resource.Output{
-						Known:        known,
-						Secret:       secret,
-						Dependencies: deps,
+					expectedValue := value.expected
+					if !known || secret || len(deps) > 0 {
+						v := resource.Output{
+							Known:        known,
+							Secret:       secret,
+							Dependencies: deps,
+						}
+						if known {
+							v.Element = value.expected
+						}
+						expectedValue = resource.NewOutputProperty(v)
 					}
-					if known {
-						expected.Element = value.expected
+
+					expected := resource.PropertyMap{"value": expectedValue}
+					if value.value == nil && known && !secret && len(deps) == 0 {
+						// marshalInputs excludes plain nil values.
+						expected = resource.PropertyMap{}
 					}
 
 					name := fmt.Sprintf("value=%v, known=%v, secret=%v, deps=%v", value, known, secret, deps)
 					t.Run(name, func(t *testing.T) {
-						inputs := Map{"value": out}
-						expected := resource.PropertyMap{"value": resource.NewOutputProperty(expected)}
 						actual, _, _, err := marshalInputs(inputs)
 						assert.NoError(t, err)
 						assert.Equal(t, expected, actual)
@@ -1129,6 +1138,42 @@ func (o TemplateTagSpecificationArrayOutput) ToTemplateTagSpecificationArrayOutp
 	return o
 }
 
+type bucketObjectArgs struct {
+	Source AssetOrArchive `pulumi:"source"`
+}
+
+type BucketObjectArgs struct {
+	Source AssetOrArchiveInput
+}
+
+func (BucketObjectArgs) ElementType() reflect.Type {
+	return reflect.TypeOf((*bucketObjectArgs)(nil)).Elem()
+}
+
+type myResourceArgs struct {
+	Res Resource `pulumi:"res"`
+}
+
+type MyResourceArgs struct {
+	Res ResourceInput
+}
+
+func (MyResourceArgs) ElementType() reflect.Type {
+	return reflect.TypeOf((*myResourceArgs)(nil)).Elem()
+}
+
+type myNestedOutputArgs struct {
+	Nested interface{} `pulumi:"nested"`
+}
+
+type MyNestedOutputArgs struct {
+	Nested Input
+}
+
+func (MyNestedOutputArgs) ElementType() reflect.Type {
+	return reflect.TypeOf((*myNestedOutputArgs)(nil)).Elem()
+}
+
 func TestOutputValueMarshallingNested(t *testing.T) {
 	ctx, err := NewContext(context.Background(), RunInfo{})
 	assert.Nil(t, err)
@@ -1149,6 +1194,26 @@ func TestOutputValueMarshallingNested(t *testing.T) {
 	unknownStringOutput := ctx.newOutput(stringOutputType).(StringOutput)
 	unknownStringOutput.getState().resolve("", false /*known*/, false /*secret*/, nil)
 
+	assetOutputType := reflect.TypeOf((*AssetOutput)(nil)).Elem()
+	fileAssetOutput := ctx.newOutput(assetOutputType).(AssetOutput)
+	fileAssetOutput.getState().resolve(&asset{path: "foo.txt"}, true /*known*/, false /*secret*/, nil)
+	fileAssetSecretOutput := ctx.newOutput(assetOutputType).(AssetOutput)
+	fileAssetSecretOutput.getState().resolve(&asset{path: "foo.txt"}, true /*known*/, true /*secret*/, nil)
+	fileAssetOutputDeps := ctx.newOutput(assetOutputType).(AssetOutput)
+	fileAssetOutputDeps.getState().resolve(&asset{path: "foo.txt"}, true /*known*/, false, /*secret*/
+		[]Resource{newSimpleCustomResource(ctx, "fakeURN", "fakeID")})
+
+	anyOutputType := reflect.TypeOf((*AnyOutput)(nil)).Elem()
+
+	nestedOutput := ctx.newOutput(anyOutputType).(AnyOutput)
+	nestedOutput.getState().resolve(fileAssetOutput, true /*known*/, false /*secret*/, nil)
+
+	nestedPtrOutput := ctx.newOutput(anyOutputType).(AnyOutput)
+	nestedPtrOutput.getState().resolve(&fileAssetOutput, true /*known*/, false /*secret*/, nil)
+
+	nestedNestedOutput := ctx.newOutput(anyOutputType).(AnyOutput)
+	nestedNestedOutput.getState().resolve(nestedOutput, true /*known*/, false /*secret*/, nil)
+
 	tests := []struct {
 		name     string
 		input    Input
@@ -1277,6 +1342,114 @@ func TestOutputValueMarshallingNested(t *testing.T) {
 				}),
 			}),
 		},
+		{
+			name: "bucket object with file asset",
+			input: &BucketObjectArgs{
+				Source: NewFileAsset("foo.txt"),
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"source": resource.NewAssetProperty(&resource.Asset{
+					Path: "foo.txt",
+				}),
+			}),
+		},
+		{
+			name: "bucket object with file archive",
+			input: &BucketObjectArgs{
+				Source: NewFileArchive("bar.zip"),
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"source": resource.NewArchiveProperty(&resource.Archive{
+					Path: "bar.zip",
+				}),
+			}),
+		},
+		{
+			name: "bucket object with file asset output",
+			input: &BucketObjectArgs{
+				Source: fileAssetOutput,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"source": resource.NewAssetProperty(&resource.Asset{
+					Path: "foo.txt",
+				}),
+			}),
+		},
+		{
+			name: "bucket object with file asset secret output",
+			input: &BucketObjectArgs{
+				Source: fileAssetSecretOutput,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"source": resource.NewOutputProperty(resource.Output{
+					Element: resource.NewAssetProperty(&resource.Asset{
+						Path: "foo.txt",
+					}),
+					Known:  true,
+					Secret: true,
+				}),
+			}),
+		},
+		{
+			name: "bucket object with file asset with deps",
+			input: &BucketObjectArgs{
+				Source: fileAssetOutputDeps,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"source": resource.NewOutputProperty(resource.Output{
+					Element: resource.NewAssetProperty(&resource.Asset{
+						Path: "foo.txt",
+					}),
+					Known:        true,
+					Dependencies: []resource.URN{"fakeURN"},
+				}),
+			}),
+		},
+		{
+			name: "resource",
+			input: &MyResourceArgs{
+				Res: NewResourceInput(newSimpleCustomResource(ctx, "fakeURN", "fakeID")),
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"res": resource.NewResourceReferenceProperty(resource.ResourceReference{
+					URN: "fakeURN",
+					ID:  resource.NewStringProperty("fakeID"),
+				}),
+			}),
+		},
+		{
+			name: "nested output",
+			input: &MyNestedOutputArgs{
+				Nested: nestedOutput,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"nested": resource.NewAssetProperty(&resource.Asset{
+					Path: "foo.txt",
+				}),
+			}),
+		},
+		{
+			name: "nested ptr output",
+			input: &MyNestedOutputArgs{
+				Nested: nestedPtrOutput,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"nested": resource.NewAssetProperty(&resource.Asset{
+					Path: "foo.txt",
+				}),
+			}),
+		},
+		{
+			name: "nested nested output",
+			input: &MyNestedOutputArgs{
+				Nested: nestedNestedOutput,
+			},
+			expected: resource.NewObjectProperty(resource.PropertyMap{
+				"nested": resource.NewAssetProperty(&resource.Asset{
+					Path: "foo.txt",
+				}),
+			}),
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
